# jason-json

[![PyPI version](
  https://badge.fury.io/py/jason-json.svg
  )](
  https://badge.fury.io/py/jason-json
) [![Maintainability](
  https://api.codeclimate.com/v1/badges/20d58be4ccf5c4c8e008/maintainability
  )](
    https://codeclimate.com/github/eggplants/jason-json/maintainability
) [![pre-commit.ci status](
  https://results.pre-commit.ci/badge/github/eggplants/jason-json/master.svg
  )](
  https://results.pre-commit.ci/latest/github/eggplants/jason-json/master
)

[![ghcr latest](
  https://ghcr-badge.herokuapp.com/eggplants/jason-json/latest_tag?trim=major&label=latest
) ![ghcr size](
  https://ghcr-badge.herokuapp.com/eggplants/jason-json/size)
](
  https://github.com/eggplants/jason-json/pkgs/container/getjump
)

[Jason](https://jason.co.jp) JSON Builder

## License

MIT
